@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play a MIDI score in real-time
 
-our $VERSION = '0.0106';
+our $VERSION = '0.0107';
 
 use strict;
 use warnings;
@@ -118,7 +118,7 @@ MIDI::RtMidi::ScorePlayer - Play a MIDI score in real-time
 
 =head1 VERSION
 
-version 0.0106
+version 0.0107
 
 =head1 SYNOPSIS
 
@@ -158,19 +158,21 @@ C<MIDI::RtMidi::ScorePlayer> plays a MIDI score in real-time.
 
 =head2 Hints
 
-B<Linux>: Timidity support requires timidity in daemon mode If your
-distro does not install a service, do: C<timidity -iAD>. Also,
-FluidSynth is an alternative to Timidity++
+B<Linux>: If your distro does not install a service, you can use
+timidity in daemon mode: C<timidity -iAD>. Also, FluidSynth is an
+alternative.
 
 B<MacOS>: You can get General MIDI via DLSMusicDevice within Logic or
 Garageband. You will need a soundfont containing drum patches in
 '~/Library/Audio/Sounds/Banks/' and DLSMusicDevice open in Garageband
-or Logic with this sound front selected. DLSMusicDevice should receive
-input from the virtual port opened below. See L<MIDI::RtMidi::FFI::Device>
-docs for more info. Alternatively you can use FluidSynth, like
+or Logic with this soundfont selected. See the
+L<MIDI::RtMidi::FFI::Device> docs for more info. Alternatively you can
+use FluidSynth:
 C<fluidsynth -a coreaudio -m coremidi -g 1.0 ~/Music/some-soundfont.sf2>.
 Also, you can use C<timidity> too.
 
+For B<Windows>, this should I<just work> out of the box.
+
 =head1 METHODS
 
 =head2 new
